=======
History
=======

0.8.x
-------------------
* Changed package name to `Pantea` 

0.7.x
-------------------
* Refactored structure including design, documentation, and performance (JIT kernels)
* Refactored RuNNer dataset

0.6.x
-------------------
* Implemented Molecular dynamics (MD) simulator
* Added Monte-Carlo (MC) simulator

0.5.x
-------------------
* Implemented Kalman filter trainer 

0.4.x
-------------------
* Applied extensive refactoring
* Replaced `PyTorch` main dependency with `JAX`
* First release on PyPI.

0.3.x
-------------------
* `JAX` optimizations applied to the `ACSF` descriptor

0.2.x
-------------------
* Some optimizations using `torch.jit.script`

0.1.x
-------------------
* Primary implementation and validation